import { getHttpClientLogger } from '../../logger.js';
import { requestGetQueryIndexStats } from './requests/requestGetQueryIndexStats.js';
/**
 * Return the number of remaining mutations.
 * The value is the sum of the queued (not sent to the indexer yet) and
 * pending mutations (currently processed by the indexer).
 *
 * @param apiConfig
 * @param indexName
 * @param keyspace
 */
export async function getQueryIndexRemainingMutations(apiConfig, indexName, keyspace) {
    const response = await requestGetQueryIndexStats(apiConfig, indexName, keyspace);
    const responseBody = await response.text();
    const parsedStats = JSON.parse(responseBody);
    const indexStats = parsedStats[`${keyspace.bucket}:${keyspace.scope}:${keyspace.collection}:${indexName}`];
    getHttpClientLogger()?.debug('Queued documents: %d', indexStats.num_docs_queued);
    getHttpClientLogger()?.debug('Pending documents: %d', indexStats.num_docs_pending);
    return indexStats.num_docs_pending + indexStats.num_docs_queued;
}
//# sourceMappingURL=getQueryIndexRemainingMutations.js.map