/*
 * Copyright (c) 2023-Present Jonathan MASSUCHETTI <jonathan.massuchetti@dappit.fr>.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { retry } from 'ts-retry-promise';
import { getIndexerStatistics } from '../services/index.js';
import { waitOptionsModerate } from './options.js';
/**
 * Wait for the Couchbase indexer to be online.
 * This is required for you to set query indexer settings.
 */
export async function waitForQueryIndexer(apiConfig, options) {
    const resolvedOptions = {
        ...waitOptionsModerate,
        ...options,
    };
    return await retry(async () => {
        const stats = await getIndexerStatistics({
            ...apiConfig,
            timeout: 200,
        }, true);
        if (stats.indexer_state !== 'Active') {
            throw new Error('Indexer is not ready yet');
        }
    }, resolvedOptions);
}
//# sourceMappingURL=waitForQueryIndexer.js.map